<?php

	function photographer_image_attributes($image_id, $image_size_width_crop = 'full', $image_size_height_crop = 'full', $max_dimensions = false)
	{
		$image_attributes = array();
		
		if ($max_dimensions)
		{
			$image_attributes = photographer_core_image_attributes__max_dimensions($image_id, $image_size_width_crop, $image_size_height_crop);
		}
		else
		{
			$image_attributes = wp_get_attachment_image_src($image_id, $image_size_width_crop);
		}
		
		$image_attributes = array(
			'file_url' => $image_attributes[0], // Image source URL.
			'width'    => $image_attributes[1], // Image width  in pixels.
			'height'   => $image_attributes[2], // Image height in pixels.
			'alt'      => get_post_meta($image_id, '_wp_attachment_image_alt', true),
			'caption'  => get_post_field('post_excerpt', $image_id),
			'page_url' => get_attachment_link($image_id) // Attachment page.
		);
		
		return $image_attributes;
	}


/* ============================================================================================================================================= */
/* ============================================================================================================================================= */


	function photographer_photo_gallery_1($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$gallery_loading 				  = get_option('pixelwars_portfolio_gallery_loading', 'wait-for-all-images');
			$gallery_style 					  = get_option('gallery_style',                       'minimal');
			$gallery_share_button 			  = get_option('gallery_share_button',                'true');
			$gallery_fullscreen_button 		  = get_option('gallery_fullscreen_button',           'true');
			$gallery_background_color_opacity = get_option('gallery_background_color_opacity',    '1.00');
			$gallery_row_height 			  = get_option('gallery_row_height',                  '360');
			$gallery_image_load_effect 		  = get_option('gallery_image_load_effect',           'effect-4');
			
			$output .= '<div class="media-grid-wrap">';
				$output .= '<div class="pw-gallery pw-collage pw-collage-loading ' . esc_attr($gallery_loading) . '" data-gallery-style="' . esc_attr($gallery_style) . '" data-share="' . esc_attr($gallery_share_button) . '" data-fullscreen="' . esc_attr($gallery_fullscreen_button) . '" data-bg-opacity="' . esc_attr($gallery_background_color_opacity) . '" data-row-height="' . esc_attr($gallery_row_height) . '" data-effect="' . esc_attr($gallery_image_load_effect) . '" data-mobile-row-height="120">';
				
					$image_resizing = get_option('pixelwars_full_size_image_resizing', '4k');
					
					foreach ($items_in_array as $item)
					{
						$image_big_attributes = "";
						
						if     ($image_resizing == '2k')          { $image_big_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_1920'); }
						elseif ($image_resizing == 'medium')      { $image_big_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_1400'); }
						elseif ($image_resizing == 'no_resizing') { $image_big_attributes = photographer_image_attributes($item, 'full');                            }
						else                                      { $image_big_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_3840'); }
						
						$image_medium_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_1400', 'pixelwars_theme_image_size_nullx1080', $max_dimensions = true);
						$image_small_attributes  = photographer_image_attributes($item, 'pixelwars_theme_image_size_nullx500');
						
						$output .= '<a href="' . esc_url($image_big_attributes['file_url']) . '" data-size="' . esc_attr($image_big_attributes['width']) . 'x' . esc_attr($image_big_attributes['height']) . '" data-med="' . esc_url($image_medium_attributes['file_url']) . '" data-med-size="' . esc_attr($image_medium_attributes['width']) . 'x' . esc_attr($image_medium_attributes['height']) . '" data-attachment-page="' . esc_url($image_medium_attributes['page_url']) . '">';
						
							$output .= '<img alt="' . esc_attr($image_small_attributes['alt']) . '" src="' . esc_url($image_small_attributes['file_url']) . '" width="' . esc_attr($image_small_attributes['width']) . '" height="' . esc_attr($image_small_attributes['height']) . '">';
							
							$image_caption = $image_big_attributes['caption'];
							
							if ($image_caption != "")
							{
								$output .= '<figure>'. esc_html($image_caption) . '</figure>';
							}
						
						$output .= '</a>';
					}
				
				$output .= '</div>';
			$output .= '</div>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function photographer_photo_gallery_2($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$gallery_loading 		   = get_option('pixelwars_portfolio_gallery_loading', 'wait-for-all-images');
			$gallery_row_height 	   = get_option('gallery_row_height', '360');
			$gallery_image_load_effect = get_option('gallery_image_load_effect', 'effect-4');
			
			$output .= '<div class="media-grid-wrap">';
				$output .= '<div class="mfp-gallery pw-collage pw-collage-loading ' . esc_attr($gallery_loading) . '" data-row-height="' . esc_attr($gallery_row_height) . '" data-effect="' . esc_attr($gallery_image_load_effect) . '" data-mobile-row-height="120">';
				
					foreach ($items_in_array as $item)
					{
						$image_big_attributes   = photographer_image_attributes($item, 'pixelwars_theme_image_size_1920', 'pixelwars_theme_image_size_nullx1080', $max_dimensions = true);
						$image_small_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_nullx500');
						
						$title_out     = "";
						$image_caption = $image_big_attributes['caption'];
						
						if ($image_caption != "")
						{
							$title_out = 'title="' . esc_attr($image_caption) . '"';
						}
						
						$output .= '<a href="' . esc_url($image_big_attributes['file_url']) . '" ' . $title_out . '>';
						$output .= 		'<img alt="' . esc_attr($image_small_attributes['alt']) . '" src="' . esc_url($image_small_attributes['file_url']) . '" width="' . esc_attr($image_small_attributes['width']) . '" height="' . esc_attr($image_small_attributes['height']) . '">';
						$output .= '</a>';
					}
				
				$output .= '</div>';
			$output .= '</div>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function photographer_photo_gallery_3($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			global $wpdb;
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$output .= '<section class="viewjs-gallery">';
				$output .= '<figure>';
					$output .= '<ul>';
					
						foreach ($items_in_array as $item)
						{
							$image_big_attributes   = photographer_image_attributes($item, 'pixelwars_theme_image_size_1920', 'pixelwars_theme_image_size_nullx1080', $max_dimensions = true);
							$image_small_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_nullx500');
							
							$title_out     = "";
							$image_caption = $image_big_attributes['caption'];
							
							if ($image_caption != "")
							{
								$title_out = 'title="' . esc_attr($image_caption) . '"';
							}
							
							$output .= '<li>';
							$output .= 		'<a class="view" ' . $title_out . ' href="' . esc_url($image_big_attributes['file_url']) . '" rel="photos">';
							$output .= 			'<img alt="' . esc_attr($image_small_attributes['alt']) . '" src="' . esc_url($image_small_attributes['file_url']) . '">';
							$output .= 		'</a>';
							$output .= '</li>';
						}
					
					$output .= '</ul>';
				$output .= '</figure>';
			$output .= '</section> <!-- .viewjs-gallery -->';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function pixelwars__homepage_photowall_gallery($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$animation = get_option('pixelwars_homepage_photowall_animation', 'random');
			$interval  = get_option('pixelwars_homepage_photowall_interval',  '1600');
			$max_step  = get_option('pixelwars_homepage_photowall_max_step',  '3');
			
			$output .= '<div class="ri-grid ri-grid-loading" data-animation="' . esc_attr($animation) . '" data-interval="' . esc_attr($interval) . '" data-max-step="' . esc_attr($max_step) . '">';
				$output .= '<ul>';
				
					foreach ($items_in_array as $item)
					{
						$image_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_2');
						
						$output .= '<li>';
						$output .= 		'<a href="#">';
						$output .= 			'<img alt="' . esc_attr($image_attributes['alt']) . '" src="' . esc_url($image_attributes['file_url']) . '">';
						$output .= 		'</a>';
						$output .= '</li>';
					}
				
				$output .= '</ul>';
			$output .= '</div>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function pixelwars__homepage_landing_2_gallery($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$loop 			  = get_option('pixelwars_homepage_owl_carousel_loop',             'true');
			$center 		  = get_option('pixelwars_homepage_owl_carousel_center',           'true');
			$autoplay 		  = get_option('pixelwars_homepage_owl_carousel_autoplay',         'true');
			$autoplay_speed   = get_option('pixelwars_homepage_owl_carousel_autoplay_speed',   '500');
			$autoplay_timeout = get_option('pixelwars_homepage_owl_carousel_autoplay_timeout', '3000');
			
			$output .= '<div class="owl-carousel fs-slider owl-loading" data-items="1" data-loop="' . esc_attr($loop) . '" data-center="' . esc_attr($center) . '" data-mouse-drag="false" data-nav="false" data-dots="false" data-autoplay="' . esc_attr($autoplay) . '" data-autoplay-speed="' . esc_attr($autoplay_speed) . '" data-autoplay-timeout="' . esc_attr($autoplay_timeout) . '" data-nav-text-prev="' . __('prev', 'read') . '" data-nav-text-next="' . __('next', 'read') . '">';
			
				foreach ($items_in_array as $item)
				{
					$image_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_1920');
					
					$output .= '<div class="fs-slide" style="background-image: url(' . esc_url($image_attributes['file_url']) . ');"></div>';
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function pixelwars__homepage_landing_4_gallery($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$output .= '<div class="fs-slider fade-slider">' . PHP_EOL;
			
				foreach ($items_in_array as $item)
				{
					$image_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_1920', 'pixelwars_theme_image_size_nullx1080', $max_dimensions = true);
					
					$output .= '<div class="fs-slide">';
					$output .= 		'<img alt="' . esc_attr($image_attributes['alt']) . '" src="' . esc_url($image_attributes['file_url']) . '">';
					$output .= '</div>' . PHP_EOL;
				}
			
			$output .= '</div> <!-- .fs-slider .fade-slider -->';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function pixelwars__homepage_alternate_gallery($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$animation = get_option('pixelwars_homepage_ken_slider_animation', 'kenburns');
			$speed 	   = get_option('pixelwars_homepage_ken_slider_interval',  '5000');
			
			$output .= '<ul class="ken-slider" data-animation="' . esc_attr($animation) . '" data-speed="' . esc_attr($speed) . '">';
			
				foreach ($items_in_array as $item)
				{
					$image_attributes = photographer_image_attributes($item, $size);
					
					$output .= '<li>';
					$output .= 		'<img alt="' . esc_attr($image_attributes['alt']) . '" src="' . esc_url($image_attributes['file_url']) . '">';
					$output .= '</li>';
				}
			
			$output .= '</ul>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */


	function pixelwars__homepage_alternate_2_gallery($atts)
	{
		extract(
			shortcode_atts(
				array(
					'ids'     => "",
					'orderby' => "",
					'size'    => 'thumbnail'
				),
				$atts
			)
		);
		
		$output            = "";
		$items_with_commas = $ids;
		
		if ($items_with_commas != "")
		{
			$items_in_array = preg_split("/[\s]*[,][\s]*/", $items_with_commas);
			
			if ($orderby == 'rand')
			{
				shuffle($items_in_array);
			}
			
			$items            = get_option('pixelwars_homepage_owl_carousel_items',            '4');
			$loop             = get_option('pixelwars_homepage_owl_carousel_loop',             'true');
			$center           = get_option('pixelwars_homepage_owl_carousel_center',           'true');
			$mouse_drag       = get_option('pixelwars_homepage_owl_carousel_mouse_drag',       'true');
			$nav_links        = get_option('pixelwars_homepage_owl_carousel_nav_links',        'true');
			$nav_dots         = get_option('pixelwars_homepage_owl_carousel_nav_dots',         'false');
			$autoplay         = get_option('pixelwars_homepage_owl_carousel_autoplay',         'true');
			$autoplay_speed   = get_option('pixelwars_homepage_owl_carousel_autoplay_speed',   '500');
			$autoplay_timeout = get_option('pixelwars_homepage_owl_carousel_autoplay_timeout', '3000');
			
			$output .= '<div class="owl-carousel owl-loading" data-items="' . esc_attr($items) . '" data-loop="' . esc_attr($loop) . '" data-center="' . esc_attr($center) . '" data-mouse-drag="' . esc_attr($mouse_drag) . '" data-nav="' . esc_attr($nav_links) . '" data-dots="' . esc_attr($nav_dots) . '" data-autoplay="' . esc_attr($autoplay) . '" data-autoplay-speed="' . esc_attr($autoplay_speed) . '" data-autoplay-timeout="' . esc_attr($autoplay_timeout) . '" data-nav-text-prev="' . __('prev', 'read') . '" data-nav-text-next="' . __('next', 'read') . '">';
			
				foreach ($items_in_array as $item)
				{
					$image_attributes = photographer_image_attributes($item, 'pixelwars_theme_image_size_760x507');
					
					$output .= '<div>';
					$output .= 		'<img alt="' . esc_attr($image_attributes['alt']) . '" src="' . esc_url($image_attributes['file_url']) . '">';
					$output .= '</div>';
				}
			
			$output .= '</div>';
		}
		
		return $output;
	}


/* ============================================================================================================================================= */
/* ============================================================================================================================================= */


	function photographer_post_gallery($output = "", $atts = null, $content = false, $tag = false)
	{
		$new_output = $output;
		
		if (is_singular('portfolio'))
		{
			$pf_type = get_option(get_the_ID() . 'pf_type', 'Standard');
			
			if ($pf_type == 'Photo Gallery')
			{
				$new_output = photographer_photo_gallery_1($atts);
			}
			elseif ($pf_type == 'Photo Gallery 2')
			{
				$new_output = photographer_photo_gallery_2($atts);
			}
			elseif ($pf_type == 'Photo Gallery 3')
			{
				$new_output = photographer_photo_gallery_3($atts);
			}
		}
		elseif (is_page_template('template-homepage.php'))
		{
			$new_output = pixelwars__homepage_photowall_gallery($atts);
		}
		elseif (is_page_template('template-homepage_landing.php'))
		{
			$new_output = pixelwars__homepage_photowall_gallery($atts);
		}
		elseif (is_page_template('template-homepage_landing_2.php'))
		{
			$new_output = pixelwars__homepage_landing_2_gallery($atts);
		}
		elseif (is_page_template('template-homepage_landing_4.php'))
		{
			$new_output = pixelwars__homepage_landing_4_gallery($atts);
		}
		elseif (is_page_template('template-homepage_alternate.php'))
		{
			$new_output = pixelwars__homepage_alternate_gallery($atts);
		}
		elseif (is_page_template('template-homepage_alternate_2.php'))
		{
			$new_output = pixelwars__homepage_alternate_2_gallery($atts);
		}
		elseif (is_singular('post') || is_page() || is_home())
		{
			$gallery_type = get_option('pixelwars__gallery_type_for_posts_and_pages', 'Photo Gallery 2');
			
			if ($gallery_type == 'Photo Gallery')
			{
				$new_output = photographer_photo_gallery_1($atts);
			}
			elseif ($gallery_type == 'Photo Gallery 2')
			{
				$new_output = photographer_photo_gallery_2($atts);
			}
		}
		
		return $new_output;
	}
	
	add_filter('post_gallery', 'photographer_post_gallery', 10, 4);
